@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import print_function
@@ -47,7 +47,7 @@ class SubscriptionsFormatter(PrettyFormatter):
 
 class Boobill(CaptchaMixin, ReplApplication):
     APPNAME = 'boobill'
-    VERSION = '1.4'
+    VERSION = '2.0'
     COPYRIGHT = 'Copyright(C) 2012-YEAR Florent Fourcot'
     DESCRIPTION = 'Console application allowing to get/download documents and bills.'
     SHORT_DESCRIPTION = "get/download documents and bills"
@@ -60,6 +60,9 @@ class Boobill(CaptchaMixin, ReplApplication):
                            'ls':              'subscriptions',
                           }
 
+    def load_default_backends(self):
+        self.load_backends(CapDocument, storage=self.create_storage())
+
     def main(self, argv):
         self.load_config()
         return ReplApplication.main(self, argv)
