@@ -5,38 +5,38 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from weboob.tools.compat import long
 
-from .base import Capability, BaseObject, NotAvailable, Field, StringField, IntField, enum
+from .base import Capability, BaseObject, NotAvailable, Field, StringField, IntField, Enum
 from .date import DateField
 
 
 __all__ = ['BaseFile', 'CapFile']
 
 
-LICENSES = enum(
-    OTHER=u'Other license',
-    PD=u'Public Domain',
-    COPYRIGHT=u'All rights reserved',
-    CCBY=u'Creative Commons BY',
-    CCBYSA=u'Creative Commons BY-SA',
-    CCBYNC=u'Creative Commons BY-NC',
-    CCBYND=u'Creative Commons BY-ND',
-    CCBYNCSA=u'Creative Commons BY-NC-SA',
-    CCBYNCND=u'Creative Commons BY-NC-ND',
-    GFDL=u'GNU Free Documentation License')
+class LICENSES(Enum):
+    OTHER = u'Other license'
+    PD = u'Public Domain'
+    COPYRIGHT = u'All rights reserved'
+    CCBY = u'Creative Commons BY'
+    CCBYSA = u'Creative Commons BY-SA'
+    CCBYNC = u'Creative Commons BY-NC'
+    CCBYND = u'Creative Commons BY-ND'
+    CCBYNCSA = u'Creative Commons BY-NC-SA'
+    CCBYNCND = u'Creative Commons BY-NC-ND'
+    GFDL = u'GNU Free Documentation License'
 
 
 class BaseFile(BaseObject):
@@ -74,14 +74,21 @@ class BaseFile(BaseObject):
         return self.id2url(self.id)
 
 
+class SearchSort(Enum):
+    RELEVANCE = 0
+    RATING = 1
+    VIEWS = 2
+    DATE = 3
+
+
 class CapFile(Capability):
     """
     Provide file download
     """
-    (SEARCH_RELEVANCE,
-     SEARCH_RATING,
-     SEARCH_VIEWS,
-     SEARCH_DATE) = range(4)
+    SEARCH_RELEVANCE = SearchSort.RELEVANCE
+    SEARCH_RATING = SearchSort.RATING
+    SEARCH_VIEWS = SearchSort.VIEWS
+    SEARCH_DATE = SearchSort.DATE
 
     def search_file(self, pattern, sortby=SEARCH_RELEVANCE):
         """
