@@ -4,16 +4,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
@@ -25,6 +25,7 @@ from weboob.capabilities.base import BaseObject, Capability, FieldNotFound, NotA
 from weboob.exceptions import ModuleInstallError
 from weboob.tools.compat import basestring, getproxies
 from weboob.tools.log import getLogger
+from weboob.tools.json import json
 from weboob.tools.misc import iter_fields
 from weboob.tools.value import ValuesDict
 
@@ -179,7 +180,8 @@ class BackendConfig(ValuesDict):
         """
         settings = {}
         for name, value in self.items():
-            settings[name] = value.dump()
+            if not value.transient:
+                settings[name] = value.dump()
         return settings
 
     def save(self, edit=True, params=None):
@@ -199,7 +201,10 @@ class BackendConfig(ValuesDict):
         if params is not None:
             dump.update(params)
 
-        self.weboob.backends_config.add_backend(self.instname, self.modname, dump, edit)
+        if edit:
+            self.weboob.backends_config.edit_backend(self.instname, dump)
+        else:
+            self.weboob.backends_config.add_backend(self.instname, self.modname, dump)
 
 
 class Module(object):
@@ -221,33 +226,49 @@ class Module(object):
     """
     # Module name.
     NAME = None
-    # Name of the maintainer of this module.
+    """Name of the maintainer of this module."""
+
     MAINTAINER = u'<unspecified>'
-    # Email address of the maintainer.
+
     EMAIL = '<unspecified>'
-    # Version of module (for information only).
+    """Email address of the maintainer."""
+
     VERSION = '<unspecified>'
-    # Description
+    """Version of module (for information only)."""
+
     DESCRIPTION = '<unspecified>'
+    """Description"""
+
     # License of this module.
     LICENSE = '<unspecified>'
-    # Configuration required for backends.
-    # Values must be weboob.tools.value.Value objects.
+
     CONFIG = BackendConfig()
-    # Storage
+    """Configuration required for backends.
+
+    Values must be weboob.tools.value.Value objects.
+    """
+
     STORAGE = {}
-    # Browser class
+    """Storage"""
+
     BROWSER = None
-    # URL to an optional icon.
-    # If you want to create your own icon, create a 'favicon.ico' ico in
-    # the module's directory, and keep the ICON value to None.
+    """Browser class"""
+
     ICON = None
-    # Supported objects to fill
-    # The key is the class and the value the method to call to fill
-    # Method prototype: method(object, fields)
-    # When the method is called, fields are only the one which are
-    # NOT yet filled.
+    """URL to an optional icon.
+
+    If you want to create your own icon, create a 'favicon.png' icon in
+    the module's directory, and keep the ICON value to None.
+    """
+
     OBJECTS = {}
+    """Supported objects to fill
+
+    The key is the class and the value the method to call to fill
+    Method prototype: method(object, fields)
+    When the method is called, fields are only the one which are
+    NOT yet filled.
+    """
 
     class ConfigError(Exception):
         """
@@ -263,6 +284,16 @@ class Module(object):
     def __repr__(self):
         return "<Backend %r>" % self.name
 
+    def __new__(cls, *args, **kwargs):
+        """ Accept any arguments, necessary for AbstractModule __new__ override.
+
+        AbstractModule, in its overridden __new__, removes itself from class hierarchy
+        so its __new__ is called only once. In python 3, default (object) __new__ is
+        then used for next instantiations but it's a slot/"fixed" version supporting
+        only one argument (type to instanciate).
+        """
+        return object.__new__(cls)
+
     def __init__(self, weboob, name, config=None, storage=None, logger=None, nofail=False):
         self.logger = getLogger(name, parent=logger)
         self.weboob = weboob
@@ -334,6 +365,11 @@ class Module(object):
             return None
 
         kwargs['proxy'] = self.get_proxy()
+        if '_proxy_headers' in self._private_config:
+            kwargs['proxy_headers'] = self._private_config['_proxy_headers']
+            if isinstance(kwargs['proxy_headers'], basestring):
+                kwargs['proxy_headers'] = json.loads(kwargs['proxy_headers'])
+
         kwargs['logger'] = self.logger
 
         if self.logger.settings['responses_dirname']:
@@ -373,7 +409,7 @@ class Module(object):
         :rtype: iter[:class:`weboob.capabilities.base.Capability`]
         """
         for base in klass.mro():
-            if issubclass(base, Capability) and base != Capability and base != klass:
+            if issubclass(base, Capability) and base != Capability and base != klass and not issubclass(base, Module):
                 yield base
 
     def has_caps(self, *caps):
@@ -465,13 +501,25 @@ class AbstractModule(Module):
     allow to simplify code with a fake inheritance: weboob will install (if needed) and
     load a PARENT module and build our AbstractModule on top of this class.
 
-    PARENT is a mandatory attribute of any AbstractModule
+    PARENT is a mandatory attribute of any AbstractModule.
+
+    By default an AbstractModule inherits its parent backends CONFIG.
+    To add backend values, use ADDITIONAL_CONFIG.
+    To remove backend values, you must override CONFIG definition.
 
     Note that you must pass a valid weboob instance as first argument of the constructor.
     """
     PARENT = None
 
-    def __new__(cls, weboob, name, config=None, storage=None, logger=None, nofail=False):
+    ADDITIONAL_CONFIG = BackendConfig()
+    """Optional additional Values for backends, appended to parent CONFIG
+
+    Values must be weboob.tools.value.Value objects.
+    """
+
+    @classmethod
+    def _resolve_abstract(cls, weboob, name):
+        """ Replace AbstractModule parent with the real base class """
         if cls.PARENT is None:
             raise AbstractModuleMissingParentError("PARENT is not defined for module %s" % cls.__name__)
 
@@ -480,5 +528,24 @@ class AbstractModule(Module):
         except ModuleInstallError as err:
             raise ModuleInstallError('The module %s depends on %s module but %s\'s installation failed with: %s' % (name, cls.PARENT, cls.PARENT, err))
 
-        cls.__bases__ = tuple([parent] + list(cls.iter_caps()))
-        return object.__new__(cls)
+        # Parent may have defined an ADDITIONAL_CONFIG
+        if getattr(parent, 'ADDITIONAL_CONFIG', None):
+            cls.ADDITIONAL_CONFIG = BackendConfig(*(list(parent.ADDITIONAL_CONFIG.values()) + list(cls.ADDITIONAL_CONFIG.values())))
+
+        # Parent may be an AbstractModule as well
+        if hasattr(parent, '_resolve_abstract'):
+            parent._resolve_abstract(weboob, name)
+
+        parent_caps = parent.iter_caps()
+        cls.__bases__ = tuple([parent] + [cap for cap in cls.iter_caps() if cap not in parent_caps])
+        return parent
+
+    def __new__(cls, weboob, name, config=None, storage=None, logger=None, nofail=False):
+        parent = cls._resolve_abstract(weboob=weboob, name=name)
+
+        # fake backend config inheritance, override existing Values
+        # do not use CONFIG to allow the children to overwrite completely the parent CONFIG.
+        if getattr(cls, 'ADDITIONAL_CONFIG', None):
+            cls.CONFIG = BackendConfig(*(list(parent.CONFIG.values()) + list(cls.ADDITIONAL_CONFIG.values())))
+
+        return Module.__new__(cls, weboob, name, config, storage, logger, nofail)
