@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
+# it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Affero General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 
@@ -29,7 +29,7 @@ from .compat import unicode
 
 
 __all__ = ['get_backtrace', 'get_bytes_size', 'iter_fields',
-            'to_unicode', 'limit', 'find_exe']
+           'to_unicode', 'input', 'limit', 'find_exe']
 
 
 def get_backtrace(empty="Empty backtrace."):
@@ -78,16 +78,19 @@ def iter_fields(obj):
 
 def to_unicode(text):
     r"""
-    >>> to_unicode('ascii')
-    u'ascii'
-    >>> to_unicode(u'utf\xe9'.encode('UTF-8'))
-    u'utf\xe9'
-    >>> to_unicode(u'unicode')
-    u'unicode'
+    >>> to_unicode('ascii') == u'ascii'
+    True
+    >>> to_unicode(u'utf\xe9'.encode('UTF-8')) == u'utf\xe9'
+    True
+    >>> to_unicode(u'unicode') == u'unicode'
+    True
     """
     if isinstance(text, unicode):
         return text
 
+    if isinstance(text, memoryview):
+        text = text.tobytes()
+
     if not isinstance(text, bytes):
         if sys.version_info.major >= 3:
             return unicode(text)
@@ -108,12 +111,21 @@ def to_unicode(text):
     return text.decode('windows-1252', 'replace')
 
 
+# Get Python 3 input function in Python2, impl here because of reliance on to_unicode
+if sys.version_info.major >= 3:
+    from builtins import input
+    raw_input = input  # pyflakes3 is satisfied
+else:
+    def input(prompt=''):
+        return raw_input(to_unicode(prompt).encode(sys.stdout.encoding or 'UTF-8'))
+
+
 def guess_encoding(stdio):
     try:
         encoding = stdio.encoding or locale.getpreferredencoding()
     except AttributeError:
         encoding = None
-    # ASCII or ANSII is most likely a user mistake
+    # ASCII or ANSI is most likely a user mistake
     if not encoding or encoding.lower() == 'ascii' or encoding.lower().startswith('ansi'):
         encoding = 'UTF-8'
     return encoding
@@ -188,4 +200,3 @@ def find_exe(basename):
             fpath = os.path.join(path, ex)
             if os.path.exists(fpath) and os.access(fpath, os.X_OK):
                 return fpath
-
