@@ -20,12 +20,9 @@
 
 import re
 import time
-import subprocess
-
 from collections import OrderedDict
-from subprocess import check_output
 
-from weboob.tools.compat import basestring, unicode
+from weboob.tools.compat import unicode
 
 from .misc import to_unicode
 
@@ -61,10 +58,13 @@ class Value(object):
     :param regexp: if specified, on load the specified value is checked against this regexp, and an error is raised if it doesn't match
     :type regexp: str
     :param choices: if this parameter is set, the value must be in the list
+    :type choices: (list,dict)
     :param aliases: mapping of old choices values that should be accepted but not presented
     :type aliases: dict
     :param tiny: the value of choices can be entered by an user (as they are small)
-    :type choices: (list,dict)
+    :type tiny: bool
+    :param transient: this value is not persistent (asked only if needed)
+    :type transient: bool
     """
 
     def __init__(self, *args, **kwargs):
@@ -83,6 +83,7 @@ class Value(object):
         if isinstance(self.choices, (list, tuple)):
             self.choices = OrderedDict(((v, v) for v in self.choices))
         self.tiny = kwargs.get('tiny', None)
+        self.transient = kwargs.get('transient', None)
         self.masked = kwargs.get('masked', False)
         self.required = kwargs.get('required', self.default is None)
         self._value = kwargs.get('value', None)
@@ -99,10 +100,10 @@ class Value(object):
 
         :raises: ValueError
         """
-        if self.default is not None and v == self.default:
-            return
         if self.required and v is None:
             raise ValueError('Value is required and thus must be set')
+        if v == self.default:
+            return
         if v == '' and self.default != '' and (self.choices is None or v not in self.choices):
             raise ValueError('Value can\'t be empty')
         if self.regexp is not None and not re.match(self.regexp + '$', unicode(v) if v is not None else ''):
@@ -147,12 +148,16 @@ class Value(object):
         """
         return self._value
 
-    def is_command(self, v):
-        """
-        Test if a value begin with ` and end with `
-        (`command` is used to call external programms)
-        """
-        return isinstance(v, basestring) and v.startswith(u'`') and v.endswith(u'`')
+
+class ValueTransient(Value):
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('transient', True)
+        kwargs.setdefault('default', None)
+        kwargs.setdefault('required', False)
+        super(ValueTransient, self).__init__(*args, **kwargs)
+
+    def dump(self):
+        return ''
 
 
 class ValueBackendPassword(Value):
@@ -167,15 +172,6 @@ class ValueBackendPassword(Value):
         self.default = kwargs.get('default', '')
 
     def load(self, domain, password, requests):
-        if self.is_command(password):
-            cmd = password[1:-1]
-            try:
-                password = check_output(cmd, shell=True)
-            except subprocess.CalledProcessError as e:
-                raise ValueError(u'The call to the external tool failed: %s' % e)
-            else:
-                password = password.decode('utf-8')
-                password = password.partition('\n')[0].strip('\r\n\t')
         self.check_valid(password)
         self._domain = domain
         self._value = to_unicode(password)
@@ -188,10 +184,6 @@ class ValueBackendPassword(Value):
         return super(ValueBackendPassword, self).check_valid(passwd)
 
     def set(self, passwd):
-        if self.is_command(passwd):
-            self._value = passwd
-            return
-
         self.check_valid(passwd)
         if passwd is None:
             # no change
@@ -203,14 +195,7 @@ class ValueBackendPassword(Value):
             self._value = to_unicode(passwd)
             return
 
-        try:
-            raise ImportError('Keyrings are disabled (see #706)')
-            import keyring
-            keyring.set_password(self._domain, self.id, passwd)
-        except Exception:
-            self._value = to_unicode(passwd)
-        else:
-            self._value = ''
+        self._value = to_unicode(passwd)
 
     def dump(self):
         if self._stored:
@@ -222,13 +207,7 @@ class ValueBackendPassword(Value):
         if self._value != '' or self._domain is None:
             return self._value
 
-        try:
-            raise ImportError('Keyrings are disabled (see #706)')
-            import keyring
-        except ImportError:
-            passwd = None
-        else:
-            passwd = keyring.get_password(self._domain, self.id)
+        passwd = None
 
         if passwd is not None:
             # Password has been read in the keyring.
@@ -308,7 +287,7 @@ class ValueDate(Value):
 
     def check_valid(self, v):
         super(ValueDate, self).check_valid(v)
-        if not self.get_format(v):
+        if v is not None and not self.get_format(v):
             raise ValueError('Value "%s" does not match format in %s' % (self.show_value(v), self.show_value(self.formats_tuple)))
 
     def get(self):
